/*
Example for Airquality6 Click

    Date          : May 2020.
    Author        : Luka Filipovic

Test configuration PIC32 :

    MCU                : P32MX795F512L
    Dev. Board         : EasyPIC Fusion v7
    PIC32 Compiler ver : v4.0.0.0

---

Description :

The application is composed of three sections :

- sys_init - Initialization of i2c and log modules,  and additional pins
- app_cfg - Reading device information and configuring device
- app_task - Reading values from device

*/

#include "stdint.h"
#include "mcu_driver.h"
#include "driver.h"

#define TEMPERATURE     1
#define MAGNETO         2

static uint8_t demo_type;
static uint8_t temp_data;
static char demo_txt[ 30 ];
static int16_t sens_data;
static magneto6_axes_t axes_val;

void sys_init ( void );

void app_cfg ( uint8_t app_type );

void app_task ( void );

void main(  )
{
    sys_init(  );
    app_cfg( MAGNETO );

    for ( ; ; )
    {
        app_task(  );
    }
}

void sys_init ( void )
{
    define_cs( OUTPUT );
    define_int( INPUT );
    IEN = 0;
    dev_i2c_init(  );
    Delay_ms( 100 );
    log_init(  );
    Delay_ms( 100 );
    log_line( " - Init -" );
}

void app_cfg ( uint8_t app_type )
{
    demo_type = app_type;

    magneto6_generic_write( MAGNETO6_REG_CFG,
                            MAGNETO6_TRIGGER_NO,
                            MAGNETO6_CFG_ID );
    magneto6_generic_write( MAGNETO6_REG_CTRL_1,
                            MAGNETO6_TRIGGER_NO,
                            MAGNETO6_CTRL1_INT_DISABLE );

    temp_data = magneto6_get_id(  );
    ByteToStr( temp_data, demo_txt );
    log_text( " ID: " );
    Ltrim( demo_txt );
    log_line( demo_txt );
    Delay_ms( 100 );
    temp_data = magneto6_get_type(  );
    ByteToStr( temp_data, demo_txt );
    log_text( " Type: " );
    Ltrim( demo_txt );
    log_line( demo_txt );
    Delay_ms( 100 );
    temp_data = magneto6_get_hw_ver(  );
    ByteToStr( temp_data, demo_txt );
    Ltrim( demo_txt );
    log_text( " HW version: " );
    log_line( demo_txt );
    Delay_ms( 100 );
    
    switch ( demo_type )
    {
    case TEMPERATURE:
        magneto6_generic_write( MAGNETO6_REG_CFG,
                                MAGNETO6_TRIGGER_NO,
                                MAGNETO6_CFG_TEMPEARATURE );
        break;
    case MAGNETO:
        magneto6_generic_write( MAGNETO6_REG_CFG,
                                MAGNETO6_TRIGGER_NO,
                                MAGNETO6_CFG_MAGNETO );
        break;
    default:
        log_line( " - ERROR - " );
        for( ; ; );
    }

    log_line( " - Task - " );
    Delay_ms( 100 );
}

void app_task ( void )
{
    if ( TEMPERATURE == demo_type )
    {
        sens_data = magneto6_get_temp_value( );
        IntToStr( sens_data, demo_txt );
        Ltrim( demo_txt );
        log_text( " Temperature: " );
        log_line( demo_txt );
    }
    else
    {
        magneto6_get_axes_value( &axes_val );
        IntToStr( axes_val.x, demo_txt );
        Ltrim( demo_txt );
        log_text( " X: " );
        log_line( demo_txt );

        IntToStr( axes_val.y, demo_txt );
        Ltrim( demo_txt );
        log_text( " Y: " );
        log_line( demo_txt );

        IntToStr( axes_val.z, demo_txt );
        Ltrim( demo_txt );
        log_text( " Z: " );
        log_line( demo_txt );
    }

    log_line( "----------------------" );
    Delay_ms( 1000 );
}