#ifndef MCU_DRIVER
#define MCU_DRIVER

#include "stdint.h"

#define IEN                          LATA4_bit//CS_pin
#define INT                          RE8_bit//INT_pin

#define INPUT                        1
#define OUTPUT                       0

//----------------------------------------------------------------GPIO

/**
 * @brief Generic function for setting cs io state
 * 
 * @param[in]    io_state         i/o macro
 */
void define_cs ( uint8_t io_state );

/**
 * @brief Generic function for setting int io state
 * 
 * @param[in]    io_state         i/o macro
 */
void define_int ( uint8_t io_state );

//----------------------------------------------------------------LOG

/**
 * @brief Generic function for initialization of log
 */
void log_init ( void );

/**
 * @brief Generic function for writing text data
 * 
 * @param[in]    txt_data         string to be written
 */
void log_text ( uint8_t *txt_data );

/**
 * @brief Generic function for writing text data with new line
 * 
 * @param[in]    txt_data         string to be written
 */
void log_line ( uint8_t *txt_data );

//----------------------------------------------------------------I2C

/**
 * @brief Generic function for initialization of i2c on the MIKROBUS_1
 */
void dev_i2c_init ( void );

/**
 * @brief Generic function for sending start signal to the device 
 */
void dev_i2c_start ( void );

/**
 * @brief Generic function for sending stop signal to the device 
 */
void dev_i2c_stop ( void );

/**
 * @brief Generic function for sending byte to the device
 * 
 * @param[in]    reg_adr         register address
 */
void dev_i2c_write ( uint8_t tx_byte );

/**
 * @brief Generic function for getting byte from the device
 * 
 * @return rx data
 */
uint8_t dev_i2c_read ( void );

#endif